from abstract_apis import *
from abstract_math import divide_it,add_it,multiply_it,subtract_it
from abstract_flask import *
from abstract_webtools.managers.urlManager import urlManager
from abstract_webtools import get_corrected_url
from abstract_webtools.managers.soupManager import soupManager,get_soup_text
from abstract_ai.gpt_classes.prompt_selection.PromptBuilder import recursive_chunk
from abstract_utilities import SingletonMeta
from abstract_utilities import (
    get_logFile,
    safe_read_from_json,
    safe_dump_to_file,
    safe_dump_to_json,
    safe_dump_to_file,
    get_any_value,
    make_list,
    make_list,
    get_logFile,
    safe_load_from_file,
    safe_read_from_json,
    get_any_value,
    SingletonMeta,
    get_env_value,
    timestamp_to_milliseconds,
    format_timestamp,
    get_time_now_iso,
    parse_timestamp,
    get_logFile,
    url_join,
    make_dirs,
    safe_dump_to_file,
    safe_read_from_json,
    read_from_file,
    write_to_file,
    path_join,
    confirm_type,
    get_media_types,
    get_all_file_types,
    eatInner,
    eatOuter,
    eatAll,
    get_any_value,
    get_all_file_types,
    is_media_type,
    safe_load_from_json,
    get_file_map,
    get_logFile,
    safe_dump_to_file,
    get_time_stamp,
    SingletonMeta,
    is_number,
    get_closest_match_from_list
    )

from abstract_webtools.managers.videoDownloader import (
    VideoDownloader
    )
from abstract_database.managers.connectionManager import *
